Documentation
¶
Index ¶
- func ColorText(text, colorName string) string
- func Contains(slice []string, item string) bool
- func FilterContainersByRestrict(containers []string, restrict string) ([]string, error)
- func FormatDuration(timestamp string) string
- func GetDisplayWidth(s string) int
- func IsBashShell(shell string) bool
- func PadToWidth(s string, width int) string
- func ResourceName(value string) string
- func StripANSI(s string) string
- func TerminalWidth() int
- func Which(program string) string
- type RealRunner
- type Runner
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FilterContainersByRestrict ¶
FilterContainersByRestrict filters a list of containers by a regex pattern
func FormatDuration ¶
FormatDuration converts a Kubernetes timestamp to a human-readable duration
func GetDisplayWidth ¶
GetDisplayWidth calculates the actual display width of a string
func IsBashShell ¶
IsBashShell checks if the shell path looks like bash
func PadToWidth ¶
PadToWidth pads a string to a specific display width
func ResourceName ¶ added in v1.2.0
ResourceName returns the name portion from a resource/name string.
func TerminalWidth ¶ added in v1.2.0
func TerminalWidth() int
TerminalWidth returns the current terminal width or a sensible default.
Types ¶
Click to show internal directories.
Click to hide internal directories.